множина = set
текст = str
словник = dict
список = list
логічне = bool
число = int
